/**
 ******************************************************************************
 *
 * @file        MG82F6P32_ADC_DRV.h
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     v1.00
 * @date        2024/03/14
 * @copyright   Copyright (c) 2019 MegaWin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */

#ifndef _MG82F6P32_ADC_DRV_H
#define _MG82F6P32_ADC_DRV_H




/**
 *******************************************************************************
 * @brief       Enable ADC block
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_Enable();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_Enable()\
    MWT(\
        ADCON0 = ADCON0 | ADCEN;\
       )

/**
 *******************************************************************************
 * @brief       Disable ADC block
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_Disable();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_Disable()\
    MWT(\
        ADCON0 &= ~ADCEN;\
       )

/**
 *******************************************************************************
 * @brief       ADC Start of conversion
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_Start();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_Start()\
    MWT(\
        ADCON0 = ADCON0 | ADCS;\
       )

/**
 *******************************************************************************
 * @brief       Clear ADC interrupt flag
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_ClearFlag()\
    MWT(\
        ADCON0 = ADCON0 & ~(ADCI);\
       )

/**
 *******************************************************************************
 * @brief       Clear ADC window compare interrupt flag
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_ClearWindowFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_ClearWindowFlag()\
    MWT(\
        ADCON0 = ADCON0 & ~(ADCWI);\
       )

/**
 *******************************************************************************
 * @brief       Clear ADC channel sample & hold flag
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_ClearSampleFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_ClearSampleFlag()\
    MWT(\
        ADCFG0 = ADCFG0 & ~(SMPF);\
       )

/**
 *******************************************************************************
 * @brief       Configure ADC input.
 * @details
 * @param[in]   __INPUTDEF__ : ADC Channel input pin.
 *  @arg\b      AIN0 : select P10
 *  @arg\b      AIN1 : select P11
 *  @arg\b      AIN2 : select P12
 *  @arg\b      AIN3 : select P13
 *  @arg\b      AIN4 : select P14
 *  @arg\b      AIN5 : select P15
 *  @arg\b      AIN6 : select P16
 *  @arg\b      AIN7 : select P17
 *  @arg\b      OP0O : select internal OP0 output
 *  @arg\b      VSS : select internal VSS
 *  @arg\b      OP1O : select internal OP1 output
 *  @arg\b      VDD_DIV_4 : select internal 1/4 VDD
 *  @arg\b      INTVREF24 : select internal Vref 2.4V.Need to enable IVREF.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_PinMux_Select(AIN0);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_Channel_input
#define AIN0      (0x00)
#define AIN1      (0x01)
#define AIN2      (0x02)
#define AIN3      (0x03)
#define AIN4      (0x04)
#define AIN5      (0x05)
#define AIN6      (0x06)
#define AIN7      (0x07)
#define OP0O      (0x08)
#define VSS       (0x09)
#define OP1O      (0x0A)
#define VDD_DIV_4 (0x0B)
#define INTVREF24 (0x0C)
/// @endcond

#define __DRV_ADC_PinMux_Select(__INPUTDEF__)\
      MWT(\
          ADCON0 = (ADCON0 & ~(CHS3 | CHS2 | CHS1 | CHS0)) | (__INPUTDEF__& (CHS3 | CHS2 | CHS1 | CHS0));\
          ADCFG0 = (ADCFG0 & ~(ACHS)) | (__INPUTDEF__& (ACHS));\
        )

/**
 *******************************************************************************
 * @brief       Polling for regular conversion complete.
 * @details     When the ADC conversion is completed, the flag(ADCI) will be 1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_PollForConversion();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_PollForConversion()\
        while((ADCON0 & ADCI) != ADCI)\

/**
 *******************************************************************************
 * @brief       Configure ADC Conversion Clock.
 * @details
 * @param[in]   __CLOCKDEF__ :  specifies the ADC Conversion Clock.
 *  @arg\b      ADC_SYSCLK_DIV_1: ADC clock source by system clock with divider 1  (default)
 *  @arg\b      ADC_SYSCLK_DIV_2: ADC clock source by system clock with divider 2
 *  @arg\b      ADC_SYSCLK_DIV_4: ADC clock source by system clock with divider 4
 *  @arg\b      ADC_SYSCLK_DIV_8: ADC clock source by system clock with divider 8
 *  @arg\b      ADC_SYSCLK_DIV_16: ADC clock source by system clock with divider 16
 *  @arg\b      ADC_SYSCLK_DIV_32: ADC clock source by system clock with divider 32
 *  @arg\b      ADC_S0TOF_DIV_2: ADC clock source by S0 overflow with divider 2
 *  @arg\b      ADC_T2OF_DIV_2: ADC clock source by Timer2 overflow with divider 2
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_ClockSource_Select(ADC_SYSCLK_DIV_8);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_Conversion_Clock
#define ADC_SYSCLK_DIV_1     (0x00)
#define ADC_SYSCLK_DIV_2     (0x20)
#define ADC_SYSCLK_DIV_4     (0x40)
#define ADC_SYSCLK_DIV_8     (0x60)
#define ADC_SYSCLK_DIV_16    (0x80)
#define ADC_SYSCLK_DIV_32    (0xA0)
#define ADC_S0TOF_DIV_2      (0xC0)
#define ADC_T2OF_DIV_2       (0xE0)
/// @endcond

#define __DRV_ADC_ClockSource_Select(__CLOCKDEF__)\
     MWT(\
          ADCFG0 = ADCFG0 & 0x1F;\
          ADCFG0 = ADCFG0 | __CLOCKDEF__;\
         )

/**
 *******************************************************************************
 * @brief       Configure ADC conversion data Alignment mode
 * @details
 * @param[in]   __ALIGNMODE__ : data alignment mode select (Right/Left)
 *  @arg\b      ADC_LEFT_JUSTIFIED : ADC result Left-Justified (default)
 *  @arg\b      ADC_RIGHT_JUSTIFIED : ADC result Right-Justified
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_DataAlignment_Select(ADC_RIGHT_JUSTIFIED);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_conversion_data_format
#define ADC_LEFT_JUSTIFIED  (0x00)
#define ADC_RIGHT_JUSTIFIED  (0x10)
/// @endcond

#define __DRV_ADC_DataAlignment_Select(__ALIGNMODE__)\
      MWT(\
          __ALIGNMODE__==ADC_RIGHT_JUSTIFIED?(ADCFG0 = ADCFG0 | ADRJ):(ADCFG0 = ADCFG0 & ~(ADRJ));\
         )

/**
 *******************************************************************************
 * @brief     Enable/Disable ADC Function State
 * @details
 * @param[in] __STATE__ : configure ADC Function
 *  @arg\b    MW_DISABLE : Disable ADC Function (default)
 *  @arg\b    MW_ENABLE : Enable ADC Function
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_Cmd(__STATE__)\
      MWT(\
          __STATE__==MW_ENABLE?(ADCON0 = ADCON0 | ADCEN):(ADCON0 = ADCON0 & ~(ADCEN));\
         )

/**
 *******************************************************************************
 * @brief     Configure ADC trigger conversion source
 * @details
 * @param[in] __ADCTRGSEL__ : select conversion trigger source
 *  @arg\b    ADC_START : ADC trigger source by software (ADCS)
 *  @arg\b    ADC_TM0OF : ADC trigger source by Timer0 overflow
 *  @arg\b    ADC_FREE_RUN : ADC free run
 *  @arg\b    ADC_S0OF : ADC trigger source by S0BRG overflow
 *  @arg\b    ADC_KBIET : ADC trigger source by KBI
 *  @arg\b    ADC_INT1ET : ADC trigger source by INT1
 *  @arg\b    ADC_INT2ET : ADC trigger source by INT2
 *  @arg\b    ADC_INT3ET : ADC trigger source by INT3
 *  @arg\b    ADC_T2EXES : ADC trigger source by T2EXES
 *  @arg\b    ADC_AC0ES : ADC trigger source by AC0ES
 *  @arg\b    ADC_T3EXES : ADC trigger source by T3EXES
 *  @arg\b    ADC_OP0ES : ADC trigger source by OP0ES
 *  @arg\b    ADC_C0TOF : ADC trigger source by PTM0 overflow
 *  @arg\b    ADC_C0CMP5 : ADC trigger source by PCA0 CH5 compare
 *  @arg\b    ADC_C1CMP0_OR_C1CMP1 : ADC trigger source by PCA1 CH0/CH1 compare
 *  @arg\b    ADC_OP1ES : ADC trigger source by OP1ES
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_TriggerSource_Select(ADC_START);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_start_control_source_select
#define ADC_START   (0x00)
#define ADC_TM0OF   (0x01)
#define ADC_FREE_RUN (0x02)
#define ADC_S0OF    (0x03)
#define ADC_KBIET   (0x10)
#define ADC_INT1ET  (0x11)
#define ADC_INT2ET  (0x12)
#define ADC_INT3ET  (0x13)
#define ADC_T2EXES  (0x20)
#define ADC_AC0ES   (0x21)
#define ADC_T3EXES  (0x22)
#define ADC_OP0ES   (0x23)
#define ADC_C0TOF   (0x30)
#define ADC_C0CMP5  (0x31)
#define ADC_C1CMP0_OR_C1CMP1 (0x32)
#define ADC_OP1ES (0x33)
/// @endcond

#define __DRV_ADC_TriggerSource_Select(__ADCTRGSEL__)\
      MWT(\
          ADCFG0 = ADCFG0 & ~(ADTM1 | ADTM0);\
          ADCFG0 = ADCFG0 | (__ADCTRGSEL__ & (ADTM1 | ADTM0));\
          __DRV_SFR_PageIndex(ADCFG4_Page);\
          ADCFG4 = ADCFG4 & ~(ADTM3 | ADTM2);\
          ADCFG4 = ADCFG4 | (__ADCTRGSEL__ & (ADTM3 | ADTM2));\
          __DRV_SFR_PageIndex(0);\
         )

/**
 *******************************************************************************
 * @brief       Set extend ADC sample time
 * @details
 * @param[in]   __SAMVAL__ : configure conversion extend sample time.(0~255)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_SetExtendSampling(10);
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_SetExtendSampling(__SAMVAL__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG2_Page);\
          ADCFG2 = __SAMVAL__;\
          __DRV_SFR_PageIndex(0);\
         )

/**
 *******************************************************************************
 * @brief     Get ADC conversion data
 * @details
 * @return    ADCDH,ADCDL
 * @note
 * @par       Example
 * @code
 *    16bitReg(user define) = __DRV_ADC_GetConversionData();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_GetConversionData()\
          (ADCDH << 8 | ADCDL)\

/**
 *******************************************************************************
 * @brief       Enable/Disable IVREF(2.4V) Function State
 * @details
 * @param[in]   __STATE__ : configure IVREF Function
 *  @arg\b      MW_DISABLE : Disable internal VREF(2.4V) Function (default)
 *  @arg\b      MW_ENABLE : Enable internal VREF(2.4V) Function
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_IVREF_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_IVREF_Cmd(__STATE__)\
      MWT(\
          DRV_PageP_Read(PCON3_P);\
          __STATE__==MW_ENABLE?(IFD = IFD | IVREN_P):(IFD = IFD & ~(IVREN_P));\
          DRV_PageP_Write(PCON3_P,IFD);\
          )

/**
 *******************************************************************************
 * @brief       Enable/Disable IVR(2.4V) can be used under power down.
 * @details
 * @param[in]   __STATE__ : configure IVREF Function
 *  @arg\b      MW_DISABLE : Disable IVR keep awake at Power down mode. (default)
 *  @arg\b      MW_ENABLE : Enable IVR keep awake at Power down mode.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_IVREF_OperationInPD(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_IVREF_OperationInPD(__STATE__)\
      MWT(\
          DRV_PageP_Read(PCON3_P);\
          __STATE__==MW_ENABLE?(IFD = IFD | IVRPDE_P):(IFD = IFD & ~(IVRPDE_P));\
          DRV_PageP_Write(PCON3_P,IFD);\
          )

/**
 *******************************************************************************
 * @brief       Enable/Disable ADC channel in scan/loop mode
 * @details
 * @param[in]   __SCANCHANNELX__ : SAIN0, SAIN1 ... SVSS
 *  @arg\b      SAIN0 : select P10
 *  @arg\b      SAIN1 : select P11
 *  @arg\b      SAIN2 : select P12
 *  @arg\b      SAIN3 : select P13
 *  @arg\b      SAIN4 : select P14
 *  @arg\b      SAIN5 : select P15
 *  @arg\b      SAIN6 : select P16
 *  @arg\b      SAIN7 : select P17
 *  @arg\b      SOP0O : select internal OP0 output.(Enabling this channel will replace AIN0)
 *  @arg\b      SVSS : select internal VSS.(Enabling this channel will replace AIN1)
 *  @arg\b      SOP1O : select internal OP1 output.(Enabling this channel will replace AIN2)
 *  @arg\b      SVDD_DIV_4 : select internal 1/4 VDD.(Enabling this channel will replace AIN3)
 * @param[in]   __STATE__ : configure auto-scan control bit
 *  @arg\b      MW_DISABLE : Disable selected channels
 *  @arg\b      MW_ENABLE : Enable selected channels
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_ScanLoopChannel_Config(SAIN0|SAIN2|SAIN7,MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_scan_channel_select
#define SAIN0     (0x0001)
#define SAIN1     (0x0002)
#define SAIN2     (0x0004)
#define SAIN3     (0x0008)
#define SAIN4     (0x0010)
#define SAIN5     (0x0020)
#define SAIN6     (0x0040)
#define SAIN7     (0x0080)
#define SOP0O     (0x0101)
#define SVSS      (0x0202)
#define SOP1O     (0x0404)
#define SVDD_DIV_4  (0x0808)
/// @endcond

#define __DRV_ADC_ScanLoopChannel_Config(__SCANCHANNELX__,__STATE__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG5_Page);\
          __STATE__==MW_ENABLE?(ADCFG5 = ADCFG5 | LOBYTE(__SCANCHANNELX__)):(ADCFG5 = ADCFG5 & ~(LOBYTE(__SCANCHANNELX__)));\
          __DRV_SFR_PageIndex(ADCFG7_Page);\
          __STATE__==MW_ENABLE?(ADCFG7 = ADCFG7 | HIBYTE(__SCANCHANNELX__)):(ADCFG7 = ADCFG7 & ~(HIBYTE(__SCANCHANNELX__)));\
          __DRV_SFR_PageIndex(0);\
          )

#define __DRV_ScanLoopChannel_Config(__SCANCHANNELX__,__STATE__)\
        __DRV_ADC_ScanLoopChannel_Config(__SCANCHANNELX__,__STATE__)\

/**
 *******************************************************************************
 * @brief      Set Window Detect High Boundary value.
 * @details
 * @param[in]  __HTHRESHOLD__ : configure High Boundary value 1~4095.
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_ADC_SetHigherThreshold(4000);
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_SetHigherThreshold(__HTHRESHOLD__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG11_Page);\
          ADCFG11 = LOBYTE( __HTHRESHOLD__ << 4);\
          __DRV_SFR_PageIndex(ADCFG12_Page);\
          ADCFG12 = HIBYTE( __HTHRESHOLD__ << 4);\
          __DRV_SFR_PageIndex(0);\
         )

/**
 *******************************************************************************
 * @brief     Set Window Detect Low Boundary value.
 * @details
 * @param[in] __LTHRESHOLD__ : configure Low Boundary value 0~4094.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_SetLowerThreshold(40);
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_SetLowerThreshold(__LTHRESHOLD__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG13_Page);\
          ADCFG13 = LOBYTE( __LTHRESHOLD__ << 4);\
          __DRV_SFR_PageIndex(ADCFG14_Page);\
          ADCFG14 = HIBYTE( __LTHRESHOLD__ << 4);\
          __DRV_SFR_PageIndex(0);\
         )

/**
 *******************************************************************************
 * @brief     Enable/Disable ADC window compare interrupt
 * @details
 * @param[in] __STATE__ :  configure Window compare interrupt
 *  @arg\b    MW_DISABLE : Disable ADC window detect interrupt (default)
 *  @arg\b    MW_ENABLE : When the ADC conversion result triggers window comparison and the ADC interrupt is enabled, an interrupt will occur.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_WindowDetect_IT(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_WindowDetect_IT(__STATE__)\
      MWT(\
          __DRV_ADC_ClearWindowFlag();\
          __DRV_SFR_PageIndex(ADCFG1_Page);\
          __STATE__==MW_ENABLE?(ADCFG1 = ADCFG1 | EADCWI):(ADCFG1 = ADCFG1 & ~(EADCWI));\
          __DRV_SFR_PageIndex(0);\
          )

/**
 *******************************************************************************
 * @brief     Select ADC window compare mode
 * @details
 * @param[in] __ADC_WDSEL__ : configure window detector mode select
 *  @arg\b    ADC_WD_INSIDE : ADCWI will be set when ADCDH: ADCDL value is within the range defined by WHB and WLB. (default)
 *  @arg\b    ADC_WD_OUTSIDE : ADCWI will be set when ADCDH: ADCDL value is outside of the range defined by WHB and WLB.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_WindowDetectMode_Select(ADC_WD_INSIDE);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_window_detect_mode_select
#define ADC_WD_INSIDE   (0x00)
#define ADC_WD_OUTSIDE  (0x40)
/// @endcond

#define __DRV_ADC_WindowDetectMode_Select(__ADC_WDSEL__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG4_Page);\
          (__ADC_WDSEL__==ADC_WD_INSIDE?(ADCFG4 = ADCFG4 & ~(ADWM0)):(ADCFG4 = ADCFG4 | ADWM0));\
          __DRV_SFR_PageIndex(0);\
          )

/**
 *******************************************************************************
 * @brief     Disable ADCI interrupt.
 * @details
 * @param[in] __STATE__ : configure interrupt ignore ADCI flag
 *  @arg\b    MW_DISABLE : After the ADC conversion is completed, if the ADC interrupt is enabled, an interrupt will occur. (default)
 *  @arg\b    MW_ENABLE : No interruption will occur after ADC conversion is completed.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_IgnoreADCI_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_IgnoreADCI_Cmd(__STATE__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG1_Page);\
          __STATE__==MW_ENABLE?(ADCFG1 = ADCFG1 | IGADCI):(ADCFG1 = ADCFG1 & ~(IGADCI));\
          __DRV_SFR_PageIndex(0);\
         )

/**
 *******************************************************************************
 * @brief       ADC Resolution select,8bit or 10bit and 12bit
 * @details
 * @param[in]   __RESOLUTIONDATA__ : configure ADC Resolution
 *  @arg\b      ADC_8BIT : ADC Resolution 8bit data.
 *  @arg\b      ADC_10BIT : ADC Resolution 10bit data.
 *  @arg\b      ADC_12BIT : ADC Resolution 12bit data. (default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_DataResolution_Select(ADC_10BIT);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_Resolution_select
#define ADC_12BIT  (0x00)
#define ADC_10BIT  (0x04)
#define ADC_8BIT   (0x08)
/// @endcond

#define __DRV_ADC_DataResolution_Select(__RESOLUTIONDATA__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG3_Page);\
          ADCFG3 = ADCFG3 & ~ ( ARES1 | ARES0 );\
          ADCFG3 = ADCFG3 | (__RESOLUTIONDATA__ & (ARES1 | ARES0));\
          __DRV_SFR_PageIndex(0);\
          )

/**
 *******************************************************************************
 * @brief     ADC Data Order transfer by DMA.
 * @details
 * @param[in] __STATE__ : configure ADC data order transfer by DMA
 *  @arg\b    H_FIRST : DMA transfer ADCDH first (default)
 *  @arg\b    L_FIRST : DMA transfer ADCDL first
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_DMATransferOrder(H_FIRST);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_Data_Order_transfer_by_DMA
#define H_FIRST   (0x00)
#define L_FIRST   (0x01)
/// @endcond

#define __DRV_ADC_DMATransferOrder(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(ADCFG4_Page);\
        __STATE__==H_FIRST?(ADCFG4 = ADCFG4 | DOSD):(ADCFG4 = ADCFG4 & ~(DOSD));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     ADC Data Byte transfer by DMA.
 * @details
 * @param[in] __DMADATASIZE__ : configure ADC Data Byte transfer 1BYTE or 2BYTE by DMA.
 *  @arg\b    DRV_1BYTE : DMA transfer 1 Byte Data
 *  @arg\b    DRV_2BYTE : DMA transfer 2 Byte Data (default)
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_DMADataSize_Select(DRV_1BYTE);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_Data_Byte_transfer_by_DMA.
#define DRV_1BYTE (0x00)
#define DRV_2BYTE (0x01)
/// @endcond

#define __DRV_ADC_DMADataSize_Select(__DMADATASIZE__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG4_Page);\
          __DMADATASIZE__==DRV_1BYTE?(ADCFG4 = ADCFG4 | DBSD):(ADCFG4 = ADCFG4 & ~(DBSD));\
          __DRV_SFR_PageIndex(0);\
         )

/**
 *******************************************************************************
 * @brief     Enable/Disable ADC interrupts.
 * @details
 * @param[in] __STATE__ : configure ADC interrupts
 *  @arg\b    MW_DISABLE : Disable ADC interrupts. (default)
 *  @arg\b    MW_ENABLE : Enable ADC interrupts.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_IT_Cmd(__STATE__)\
      MWT(\
          __STATE__==MW_ENABLE?(EIE1 = EIE1 | EADC):(EIE1 = EIE1 &~(EADC));\
         )

/**
 *******************************************************************************
 * @brief     Enable/Disable ADC sample flag interrupt
 * @details
 * @param[in] __STATE__ :  configure sample flag interrupt
 *  @arg\b    MW_DISABLE : Disable sample & hold interrupt (default)
 *  @arg\b    MW_ENABLE : After completing the ADC sample & hold and the ADC interrupt is enabled, an interrupt will occur.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_SampleFlag_IT(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_SampleFlag_IT(__STATE__)\
      MWT(\
          __DRV_ADC_ClearSampleFlag();\
          __DRV_SFR_PageIndex(ADCFG1_Page);\
          __STATE__==MW_ENABLE?(ADCFG1 = ADCFG1 | SMPFIE):(ADCFG1 = ADCFG1  & ~(SMPFIE));\
          __DRV_SFR_PageIndex(0);\
          )

/**
 *******************************************************************************
 * @brief       Get ADC interrupt flag
 * @details     This flag is set when an A/D conversion is completed.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_GetFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_GetFlag()\
        (ADCON0 & ADCI)\

/**
 *******************************************************************************
 * @brief       Get ADC window compare interrupt flag
 * @details     This flag is set when ADC Window Comparison Data match has occurred.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_Window_GetFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_Window_GetFlag()\
        (ADCON0 & ADCWI)\

/**
 *******************************************************************************
 * @brief       Get ADC channel sample & hold flag
 * @details     This flag is set when an ADC channel sample & hold is completed.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_Sample_GetFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_ADC_Sample_GetFlag()\
        (ADCFG0 & SMPF)\

/**
 *******************************************************************************
 * @brief     Select ADC Voltage reference select
 * @details
 * @param[in] __ADC_VERFSEL__ : configure reference voltage  select
 *  @arg\b    ADC_VDD : ADC reference voltage is VDD. (default)
 *  @arg\b    ADC_IVR24 : ADC reference voltage is internal IVREF(2.4V). Need to enable IVREF.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_ADC_Reference_Select(ADC_IVR24);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_reference_voltage_select.
#define ADC_VDD   (0x00)
#define ADC_IVR24 (0x01)
/// @endcond

#define __DRV_ADC_Reference_Select(__ADC_VERFSEL__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG4_Page);\
          __ADC_VERFSEL__==ADC_VDD?(ADCFG4 = ADCFG4 & ~(VRS0)):(ADCFG4 = ADCFG4 | VRS0);\
          __DRV_SFR_PageIndex(0);\
          )

/**
 *******************************************************************************
 * @brief       ADC Conversion power level select,The higher the power, the faster the speed
 * @details
 * @param[in]   __POWER__ : configure ADC power level
 *  @arg\b      ADC_HIGH : High power, high speed
 *  @arg\b      ADC_MEDHIGH : Medium high power, medium high speed (default)
 *  @arg\b      ADC_MEDLOW : Medium low power, medium low speed
 *  @arg\b      ADC_LOW : Low power, low speed
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_PowerMode_Select(ADC_HIGH);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_Power_level_select.
#define ADC_HIGH    (0x00)
#define ADC_MEDHIGH (0x40)
#define ADC_MEDLOW  (0x80)
#define ADC_LOW     (0xC0)
/// @endcond

#define __DRV_ADC_PowerMode_Select(__POWER__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG3_Page);\
          ADCFG3 = ADCFG3 & ~( ADPS1 | ADPS0 );\
          ADCFG3 = ADCFG3 | (__POWER__ & (ADPS1 | ADPS0));\
          __DRV_SFR_PageIndex(0);\
          )

/**
 *******************************************************************************
 * @brief       ADC single conversion cycle.
 * @details
 * @param[in]   __CLKCYCLE__ : configure ADC conversion cycle
 *  @arg\b      ADC_30CLOCK : 30 ADC clocks for ADC conversion
 *  @arg\b      ADC_24CLOCK : 24 ADC clocks for ADC conversion (default)
 *  @arg\b      ADC_28CLOCK : 28 ADC clocks for ADC conversion
 *  @arg\b      ADC_29CLOCK : 29 ADC clocks for ADC conversion
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_ADC_ConversionCycle_Select(ADC_24CLOCK);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ADC_conversion_clock_cycle.
#define ADC_30CLOCK   (0x00)
#define ADC_24CLOCK   (0x20)
#define ADC_28CLOCK   (0x10)
#define ADC_29CLOCK   (0x30)
/// @endcond

#define __DRV_ADC_ConversionCycle_Select(__CLKCYCLE__)\
      MWT(\
          __DRV_SFR_PageIndex(ADCFG3_Page);\
          ADCFG3 = ADCFG3 & ~( ADHS | ADHS1 );\
          ADCFG3 = ADCFG3 | (__CLKCYCLE__ & (ADHS | ADHS1));\
          __DRV_SFR_PageIndex(0);\
          )

#endif
