/**
 ******************************************************************************
 *
 * @file        MG82F6P32_OPA1_DRV.h
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     v1.00
 * @date        2024/03/26
 * @copyright   Copyright (c) 2019 Megawin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */
#ifndef _MG82F6P32_OPA1_DRV_H
#define _MG82F6P32_OPA1_DRV_H
/**
 *******************************************************************************
 * @brief        Clear OPA1 interrupt flag
 * @details      Set OP1CMPF
 * @return       None
 * @note
 * @par          Example
 * @code
 *    __DRV_OPA1_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_OPA1_ClearFlag()\
    MWT(\
        OPSTA = OPSTA | OP1CMPF;\
    )

/**
 *******************************************************************************
 * @brief       MW_ENABLE/MW_DISABLE OPA1 block
 * @details     Set OP1EN
 * @param[in]   __STATE__  :
 *  @arg\b      MW_ENABLE   :Set to turn on the OPA1 block. At least 5us stable time after OPA1 is enabled.
 *  @arg\b      MW_DISABLE  :Clear to turn off the OPA1 block.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_OPA1_OP1EN_Block(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_OPA1_OP1EN_Block(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(OP1CON0_Page);\
        __STATE__==MW_ENABLE?(OP1CON0 = (OP1CON0 |OP1EN)):(OP1CON0 = OP1CON0 & ~(OP1EN));\
        __DRV_SFR_PageIndex(0);\
    )
/**
 *******************************************************************************
 * @brief     MW_ENABLE/MW_DISABLE OPA1CMPF ignore interrupt.
 * @details   Set OP1IG
 * @param[in] __STATE__  : configure Ignore OPA1CMPF flag 
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 *  @arg\b    MW_ENABLE  :OPA1CMPF ignore interrupt.
 *  @arg\b    MW_DISABLE :OPA1CMPF normal interrupt.(Default)
 * @return    None
 * @note
 * @par         Example
 * @code
 *    __DRV_OPA1_IgnoreOPA1CMPF_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_OPA1_IgnoreOPA1CMPF_Cmd(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(OP1CON0_Page);\
        __STATE__==MW_ENABLE?(OP1CON0 = (OP1CON0 |OP1IG)):(OP1CON0 = (OP1CON0 & (~IGADCI)));\
        __DRV_SFR_PageIndex(0);\
       )
/**
 *******************************************************************************
 * @brief      Select OPA1 positive input path
 * @details    Set OP1PIS1 OP1PIS0
 * @param[in]  __SELECT__  :   config positive pin 
 *  @arg\b     OPA_OPA1PI0 :   PI select Internal reference voltage Bandgap 1.2V .(default)
 *  @arg\b     OPA_OPA1PI1 :   PI select OP1PI (P2.4)
 *  @arg\b     OPA_OPA1PI2 :   PI select PGADO.
 * @return     none
 * @note
 * @par        Example
 * @code
 *    __DRV_OPA1_PositivePinMux_Select(OPA_OPA1PI0);
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_OPA1_PositivePinMux_Select
#define OPA_OPA1PI0 ~(OP1PIS1|OP1PIS0)      /*!< PI select Internal reference voltage Bandgap 1.2V */
#define OPA_OPA1PI1 OP1PIS0                 /*!< PI select OP1PI (P2.4)  */
#define OPA_OPA1PI2 OP1PIS1                 /*!< PI select PGADO  */
/// @endcond

#define __DRV_OPA1_PositivePinMux_Select(__SELECT__)\
    MWT(\
        __DRV_SFR_PageIndex(OP1CON0_Page);\
        OP1CON0 = OP1CON0 & ~(OP1PIS1 | OP1PIS0);\
        OP1CON0 = (OP1CON0 |(__SELECT__&(OP1PIS1 | OP1PIS0)));\
        __DRV_SFR_PageIndex(0);\
    )
/**
 *******************************************************************************
 * @brief      Select OPA1 negative input path
 * @details    Set OP1NIS1 OP1NIS0
 * @param[in]  __SELECT__  : config negative pin 
 *  @arg\b     OPA_OPA1NI0 : NI select Internal reference voltage Bandgap 1.2V .(default)
 *  @arg\b     OPA_OPA1NI1 : NI select OP1NI (P2.6).
 *  @arg\b     OPA_OPA1NI2 : NI select NI select OP1O, Operate as Uni-gain buffer.
 * @return     none
 * @note
 * @par        Example
 * @code
 *    __DRV_OPA1_NegativePinMux_Select(OPA_OPA1NI0);
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_OPA1_NegativePinMux_Select
#define OPA_OPA1NI0 ~(OP1NIS1|OP1NIS0)        /*!< NI select Internal reference voltage Bandgap 1.2V */
#define OPA_OPA1NI1 OP1NIS0                   /*!< NI select OP1NI (P2.6)  */
#define OPA_OPA1NI2 OP1NIS1                   /*!< NI select OP1O, Operate as Uni-gain buffer  */
/// @endcond

#define __DRV_OPA1_NegativePinMux_Select(__SELECT__)\
    MWT(\
        __DRV_SFR_PageIndex(OP1CON0_Page);\
        OP1CON0 = OP1CON0 & ~(OP1NIS1 | OP1NIS0);\
        OP1CON0 = (OP1CON0|(__SELECT__&(OP1NIS1 | OP1NIS0)));\
        __DRV_SFR_PageIndex(0);\
    )
/**
 *******************************************************************************
 * @brief      MW_ENABLE/MW_DISABLE to continue its function during PD mode.
 * @details    Set OP1PDX
 * @param[in]  __STATE__  : Configure OPA1 Operation in power down mode.
 *             This parameter can be: MW_ENABLE or MW_DISABLE.
 *  @arg\b     MW_ENABLE  : Program the OPA1 to continue its function during PD mode.
 *  @arg\b     MW_DISABLE : Program the OPA1 to be gated off during PD mode.(default)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_OPA1_OperationInPD(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_OPA1_OperationInPD(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(OPCMP_Page);\
        __STATE__==MW_ENABLE?(OPCMP = (OPCMP|OP1PDX)):(OPCMP = OPCMP & ~(OP1PDX));\
        __DRV_SFR_PageIndex(0);\
    )

/**
 *******************************************************************************
 * @brief     Set OPA1 interrupt trigger type
 * @details   Set OP1M1 OP1M0
 * @param[in] __SELECT__            : Set OPA1 interrupt trigger.
 *  @arg\b    OPA1_NO_TRIGGER       : OPA1 does not trigger interrupt.(default)
 *  @arg\b    OPA1_FALLING_TRIGGER  : OPA1 trigger interrupt on the negative edge.
 *  @arg\b    OPA1_RISING_TRIGGER   : OPA1 trigger interrupt on the positive edge.
 *  @arg\b    OPA1_DUAL_TRIGGER     : OPA1 trigger interrupt on positive and negative edges.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_OPA1_TriggerType_Select(OPA1_FALLING_TRIGGER);
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_OPA1_TriggerType_Select
#define OPA1_NO_TRIGGER       ~(OP1M1|OP1M0)
#define OPA1_FALLING_TRIGGER  OP1M0
#define OPA1_RISING_TRIGGER   OP1M1
#define OPA1_DUAL_TRIGGER     (OP1M1|OP1M0)
/// @endcond

#define __DRV_OPA1_TriggerType_Select(__SELECT__)\
    MWT(\
        __DRV_SFR_PageIndex(OPCMP_Page);\
        OPCMP = OPCMP &~(OP1M1|OP1M0);\
        OPCMP = (OPCMP|(__SELECT__&(OP1M1|OP1M0)));\
        __DRV_SFR_PageIndex(0);\
    )
/**
 *******************************************************************************
 * @brief       Get OPA1 interrupt flag
 * @details     The bit is set when the comparator output meets the conditions specified for the trigger and OP1EN is set.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_OPA1_GetFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_OPA1_GetFlag()\
    MWT(\
        OPSTA & OP1CMPF;\
    )
///@cond
bool DRV_OPA1_GetFlag(void);
///@endcond   
#endif

