/**
 ******************************************************************************
 *
 * @file        MG82F6P32_PCA1_DRV.c
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     v1.00
 * @date        2024/03/14
 * @copyright   Copyright (c) 2019 MegaWin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */

#include "MG82F6P32_CONFIG.h"

/**
*******************************************************************************
* @brief       Read PCA1 Module 0 flag.
* @details     Set by hardware when a match or capture occurs.
* @return      TRUE or FALSE
* @note        None
* @par         Example
* @code
               if(DRV_PCA1_GetModule0Flag())
                  .... //Flag=1
               else
                  .... //Flag=0
* @endcode
*******************************************************************************
*/
bool DRV_PCA1_GetModule0Flag(void)
{
    _push_(SFRPI);
    __DRV_SFR_PageIndex(C1CON_Page);
    if(C1CF0==1)
    {
        _pop_(SFRPI);
        return TRUE;
    }
    _pop_(SFRPI);
    return FALSE;
}
/**
*******************************************************************************
* @brief       Read PCA1 Module 1 flag.
* @details     Set by hardware when a match or capture occurs.
* @return      TRUE or FALSE
* @note        None
* @par         Example
* @code
               if(DRV_PCA1_GetModule1Flag())
                  .... //Flag=1
               else
                  .... //Flag=0
* @endcode
*******************************************************************************
*/
bool DRV_PCA1_GetModule1Flag(void)
{
    _push_(SFRPI);
    __DRV_SFR_PageIndex(C1CON_Page);
    if(C1CF1==1)
    {
        _pop_(SFRPI);
        return TRUE;
    }
    _pop_(SFRPI);
    return FALSE;
}

/**
*******************************************************************************
* @brief       Read PCA1 overflow flag.
* @details     Set by hardware when the counter rolls over.
* @return      TRUE or FALSE
* @note        None
* @par         Example
* @code
               if(DRV_PCA1_GetOverflowFlag())
                  .... //Flag=1
               else
                  .... //Flag=0
* @endcode
*******************************************************************************
*/
bool DRV_PCA1_GetOverflowFlag(void)
{
    _push_(SFRPI);
    __DRV_SFR_PageIndex(C1CON_Page);
    if(C1F==1)
    {
        _pop_(SFRPI);
        return TRUE;
    }
    _pop_(SFRPI);
    return FALSE;
}
/**
*******************************************************************************
* @brief       Read PCA1 PWM break flag.
* @details     0: There is no PWM Break event happened. It is only cleared by software.
               1: There is a PWM Break event happened or software triggers a PWM Break.
* @return      TRUE or FALSE
* @note        None
* @par         Example
* @code
               if(DRV_PCA1_GetBreakFlag())
                  .... //Flag=1
               else
                  .... //Flag=0
* @endcode
*******************************************************************************
*/
bool DRV_PCA1_GetBreakFlag(void)
{
    _push_(SFRPI);
    __DRV_SFR_PageIndex(0);
    if((AUXR0&C1BKF)==C1BKF)
    {
        _pop_(SFRPI);
        return TRUE;
    }
    _pop_(SFRPI);
    return FALSE;
}

/**
 *******************************************************************************
 * @brief       Get the PCA1 PWM channel 0 duty
 * @details
 * @return      16bit data from PWM 0 Duty
 * @note
 * @par         Example
 * @code
 *    16bitReg(user define) = DRV_PCA1_GetPWM0DutyValue();
 * @endcode
 *******************************************************************************
 */
uint16_t DRV_PCA1_GetPWM0DutyValue(void)
{
    uint16_t dta;
    _push_(SFRPI);
    __DRV_SFR_PageIndex(1);
    dta = (C1CAP0H << 8 | C1CAP0L);
    _pop_(SFRPI);
    return dta;
}
/**
 *******************************************************************************
 * @brief       Get the PCA1 PWM channel 1 duty
 * @details
 * @return      16bit data from PWM 1 Duty
 * @note
 * @par         Example
 * @code
 *    16bitReg(user define) = DRV_PCA1_GetPWM1DutyValue();
 * @endcode
 *******************************************************************************
 */
uint16_t DRV_PCA1_GetPWM1DutyValue(void)
{
    uint16_t dta;
    _push_(SFRPI);
    __DRV_SFR_PageIndex(1);
    dta = (C1CAP1H << 8 | C1CAP1L);
    _pop_(SFRPI);
    return dta;
}



